/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_4slVukkT);
  numBytes += sPhasor_k_init(&sPhasor_Vu88ZkfU, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_gaLHJMCL);
  numBytes += sRPole_init(&sRPole_xhuGSjEj);
  numBytes += sRPole_init(&sRPole_dV9dZwqr);
  numBytes += sTabhead_init(&sTabhead_QQtJDhte, &hTable_IBHsgGpT);
  numBytes += sTabread_init(&sTabread_PPqE36nr, &hTable_IBHsgGpT, false);
  numBytes += sTabread_init(&sTabread_w3zHKqNg, &hTable_IBHsgGpT, false);
  numBytes += sLine_init(&sLine_UaLc54IU);
  numBytes += sTabhead_init(&sTabhead_2ZryYObd, &hTable_ECZy1n7p);
  numBytes += sTabread_init(&sTabread_l6tRvSsR, &hTable_ECZy1n7p, false);
  numBytes += sTabread_init(&sTabread_OYxPP99J, &hTable_ECZy1n7p, false);
  numBytes += sLine_init(&sLine_0yaDFIlD);
  numBytes += sTabwrite_init(&sTabwrite_JL4LqR8I, &hTable_ECZy1n7p);
  numBytes += sTabwrite_init(&sTabwrite_hGGtuxGo, &hTable_IBHsgGpT);
  numBytes += cVar_init_f(&cVar_02ae8cOW, 0.0f);
  numBytes += cVar_init_f(&cVar_QSqQBbjr, 0.0f);
  numBytes += cVar_init_f(&cVar_gOrtEDfu, 0.0f);
  numBytes += cVar_init_f(&cVar_alCqMelJ, 0.0f);
  numBytes += cVar_init_s(&cVar_ngAtZV2e, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_wX9IlYUH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rwdndEls, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fgfyiWCp, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_PHrNEIqz, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_XgTNQ9XI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TE54ibm4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7EkXh9Mb, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_yIrqdCkD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BjOBFNpm, 0.0f);
  numBytes += hTable_init(&hTable_ECZy1n7p, 256);
  numBytes += cDelay_init(this, &cDelay_FpBp03cP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Pn3J598T, 0.0f);
  numBytes += hTable_init(&hTable_IBHsgGpT, 256);
  numBytes += cVar_init_f(&cVar_OhNLjxbg, 14.0f);
  numBytes += cBinop_init(&cBinop_hu8T4P7v, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Q3BMEXSE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BJE2HdFp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pJwxQl5Z, 14.0f);
  numBytes += cBinop_init(&cBinop_HksZJdYz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DI63XIlr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5OYG2F3y, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_YJH3KjIh, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_ejxMvxJU, 1, -1);
  numBytes += cVar_init_f(&cVar_wWWFXABv, 0.2f);
  numBytes += cSlice_init(&cSlice_hrw9q3Ji, 1, -1);
  numBytes += cVar_init_f(&cVar_Z1vCa3fM, 0.0f);
  numBytes += cSlice_init(&cSlice_Hzh3HMMU, 1, -1);
  numBytes += cVar_init_f(&cVar_2FnwHuqN, 2.0f);
  numBytes += cSlice_init(&cSlice_L71NtAxw, 1, -1);
  numBytes += cVar_init_f(&cVar_rFO31x27, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_ECZy1n7p);
  hTable_free(&hTable_IBHsgGpT);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_ECZy1n7p; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_IBHsgGpT; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qMOIrAnE_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_odq0yqxP_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JcoskrOv_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YiW7fRav_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JHJV8YSL_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7DcjXngj_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ek74Unop_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FsjY8muT_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eM6SWNdN_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_02ae8cOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w2yxXnpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_QSqQBbjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z5tgD1Rz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_gOrtEDfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2vNNvcBo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_alCqMelJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0DG75C3C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_YW3sv8xU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1OZR0Au7_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_1OZR0Au7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Vu88ZkfU, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_0cFtrmMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QdDiDbgY_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_QdDiDbgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_i7WrON8z_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_ngAtZV2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J8qdNQos_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_7DqZR8OS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OppkBO21_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wX9IlYUH, m);
}

void Heavy_WSTD_FLANGR::cBinop_i7WrON8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rwdndEls, m);
}

void Heavy_WSTD_FLANGR::cMsg_J8qdNQos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7DqZR8OS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_OppkBO21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fgfyiWCp, m);
}

void Heavy_WSTD_FLANGR::cMsg_Ktg6jKRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nP3vkXky_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_nP3vkXky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_o1S4oaSZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_PHrNEIqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ijuINjWt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_pq6oj3WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tGiHHFUd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XgTNQ9XI, m);
}

void Heavy_WSTD_FLANGR::cBinop_o1S4oaSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TE54ibm4, m);
}

void Heavy_WSTD_FLANGR::cMsg_ijuINjWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pq6oj3WA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_tGiHHFUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7EkXh9Mb, m);
}

void Heavy_WSTD_FLANGR::cBinop_muZe7YRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LvChgMpn_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_LvChgMpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_N6rB5NcK_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_cQxQuFQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BU3651Pw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_TkDYTgEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dGtKWRsZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_N6rB5NcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_j2gDQcsw_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_j2gDQcsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zTrM2kxI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5lUdkyOB_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_5lUdkyOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8IUuHCH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_zTrM2kxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7zNeb3GL_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7zNeb3GL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2i7pjPyV_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_u8IUuHCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DNjjAfN3_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_DNjjAfN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JPUH4q26_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2i7pjPyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_cQxQuFQH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_JPUH4q26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_TkDYTgEl_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_fbtLjg9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_G2kUbIGm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_G2kUbIGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_49FEHVlb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_Vbutb2A8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JLtlYP44_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_JLtlYP44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DvMatgIY_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_yIrqdCkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yIrqdCkD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BjOBFNpm, 0, m, &cDelay_BjOBFNpm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yIrqdCkD, 0, m, &cDelay_yIrqdCkD_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JL4LqR8I, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_BjOBFNpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BjOBFNpm, m);
  cMsg_NbOIuSGR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_gQCAGcJk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_iWFr0AMS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_wypYrauu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kNwgs15T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_ECZy1n7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_56b7jUkR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yIrqdCkD, 2, m, &cDelay_yIrqdCkD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dc2DEMYa_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_kNwgs15T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ECZy1n7p, 0, m, &hTable_ECZy1n7p_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_DvMatgIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_wypYrauu_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_NbOIuSGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ECZy1n7p, 0, m, &hTable_ECZy1n7p_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_dc2DEMYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yIrqdCkD, 0, m, &cDelay_yIrqdCkD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_56b7jUkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BjOBFNpm, 2, m, &cDelay_BjOBFNpm_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_iWFr0AMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JL4LqR8I, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_qFuOJhVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VfjpDDn3_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_VfjpDDn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6UbliJR1_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_FpBp03cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FpBp03cP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Pn3J598T, 0, m, &cDelay_Pn3J598T_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpBp03cP, 0, m, &cDelay_FpBp03cP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hGGtuxGo, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_Pn3J598T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Pn3J598T, m);
  cMsg_nXrZae8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_ziVVcW9q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_8sMSNMt8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_vQv4V0Uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g71oq06s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_IBHsgGpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iuCEhDhr_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpBp03cP, 2, m, &cDelay_FpBp03cP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fljIoIh9_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_g71oq06s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_IBHsgGpT, 0, m, &hTable_IBHsgGpT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_6UbliJR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_vQv4V0Uz_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_nXrZae8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_IBHsgGpT, 0, m, &hTable_IBHsgGpT_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_fljIoIh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpBp03cP, 0, m, &cDelay_FpBp03cP_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_iuCEhDhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Pn3J598T, 2, m, &cDelay_Pn3J598T_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_8sMSNMt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hGGtuxGo, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_OhNLjxbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hu8T4P7v, HV_BINOP_MULTIPLY, 0, m, &cBinop_hu8T4P7v_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_NZoJPd8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1iv6EMlQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_1iv6EMlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DF05SJNh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_hu8T4P7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OnBTWho8_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_AuGRsDIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hu8T4P7v, HV_BINOP_MULTIPLY, 1, m, &cBinop_hu8T4P7v_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_DF05SJNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AuGRsDIy_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_OnBTWho8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_U1O3reMP_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_U1O3reMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_efUVQll9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BJE2HdFp, m);
}

void Heavy_WSTD_FLANGR::cBinop_efUVQll9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q3BMEXSE, m);
}

void Heavy_WSTD_FLANGR::cVar_pJwxQl5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HksZJdYz, HV_BINOP_MULTIPLY, 0, m, &cBinop_HksZJdYz_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_AsZPmU4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uIaUkfup_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_uIaUkfup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RoDD1ngc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_HksZJdYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jk2UI3ww_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_3egxxNHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HksZJdYz, HV_BINOP_MULTIPLY, 1, m, &cBinop_HksZJdYz_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_RoDD1ngc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3egxxNHn_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_jk2UI3ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2Mi2MAgW_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2Mi2MAgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vDaHcpLE_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5OYG2F3y, m);
}

void Heavy_WSTD_FLANGR::cBinop_vDaHcpLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DI63XIlr, m);
}

void Heavy_WSTD_FLANGR::cMsg_49FEHVlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gaLHJMCL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_LDdXo4aC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_Hak9tqXN_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_RFW6yQjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_LDdXo4aC_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_JD8i1OpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2wteG8m9_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_4wgBzYZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fGfoTUjU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_fGfoTUjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YJH3KjIh, HV_BINOP_MULTIPLY, 1, m, &cBinop_YJH3KjIh_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2wteG8m9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_4wgBzYZA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_YJH3KjIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2MbcyUT5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Hak9tqXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YJH3KjIh, HV_BINOP_MULTIPLY, 0, m, &cBinop_YJH3KjIh_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_2MbcyUT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0yaDFIlD, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_H3HK9aKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_AQVuQsuR_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_AQVuQsuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JD8i1OpP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RFW6yQjY_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_A06MA2H9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ejxMvxJU, 0, m, &cSlice_ejxMvxJU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5jCRiYt5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_ejxMvxJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TlqePFM6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TlqePFM6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_wWWFXABv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TlqePFM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_TlqePFM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7DcjXngj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_5jCRiYt5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hrw9q3Ji, 0, m, &cSlice_hrw9q3Ji_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vS2mbe3S_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_hrw9q3Ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WbOXcLgR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WbOXcLgR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_Z1vCa3fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WbOXcLgR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_WbOXcLgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JHJV8YSL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_vS2mbe3S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Hzh3HMMU, 0, m, &cSlice_Hzh3HMMU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kePkNDEr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Hzh3HMMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7oNyD6pD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7oNyD6pD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_2FnwHuqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7oNyD6pD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_7oNyD6pD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FsjY8muT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_kePkNDEr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L71NtAxw, 0, m, &cSlice_L71NtAxw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_L71NtAxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ihtc3DUD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ihtc3DUD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_rFO31x27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ihtc3DUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_ihtc3DUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ek74Unop_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_BU3651Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UaLc54IU, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_dGtKWRsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4slVukkT, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_0DG75C3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_A06MA2H9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_w2yxXnpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_A06MA2H9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_z5tgD1Rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_A06MA2H9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_2vNNvcBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_A06MA2H9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_hmB8e75y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alCqMelJ, 0, m, &cVar_alCqMelJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_XdhZYnqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_02ae8cOW, 0, m, &cVar_02ae8cOW_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_KbYPMY5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gOrtEDfu, 0, m, &cVar_gOrtEDfu_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_FsjY8muT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_YW3sv8xU_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_JHJV8YSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_H3HK9aKe_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_eM6SWNdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NZoJPd8h_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OhNLjxbg, 0, m, &cVar_OhNLjxbg_sendMessage);
  cMsg_AsZPmU4D_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pJwxQl5Z, 0, m, &cVar_pJwxQl5Z_sendMessage);
  cMsg_Vbutb2A8_sendMessage(_c, 0, m);
  cMsg_qFuOJhVA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wWWFXABv, 0, m, &cVar_wWWFXABv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z1vCa3fM, 0, m, &cVar_Z1vCa3fM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2FnwHuqN, 0, m, &cVar_2FnwHuqN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rFO31x27, 0, m, &cVar_rFO31x27_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ngAtZV2e, 0, m, &cVar_ngAtZV2e_sendMessage);
  cMsg_0cFtrmMz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PHrNEIqz, 0, m, &cVar_PHrNEIqz_sendMessage);
  cMsg_Ktg6jKRa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_Ek74Unop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_muZe7YRv_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_7DcjXngj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fbtLjg9c_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_YiW7fRav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QSqQBbjr, 0, m, &cVar_QSqQBbjr_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_JcoskrOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hmB8e75y_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_odq0yqxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_KbYPMY5J_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_qMOIrAnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XdhZYnqm_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_4slVukkT, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_Vu88ZkfU, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_gaLHJMCL, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_BJE2HdFp, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Q3BMEXSE, VOf(Bf3));
    __hv_rpole_f(&sRPole_xhuGSjEj, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5OYG2F3y, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_DI63XIlr, VOf(Bf4));
    __hv_rpole_f(&sRPole_dV9dZwqr, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_QQtJDhte, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_rwdndEls, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_fgfyiWCp, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_wX9IlYUH, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_PPqE36nr, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_w3zHKqNg, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_UaLc54IU, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_2ZryYObd, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_TE54ibm4, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_7EkXh9Mb, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_XgTNQ9XI, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_l6tRvSsR, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_OYxPP99J, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_0yaDFIlD, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_JL4LqR8I, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_hGGtuxGo, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
