/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlDelay.h"
#include "HvSignalPhasor.h"
#include "HvSignalTabread.h"
#include "HvSignalDel1.h"
#include "HvMath.h"
#include "HvControlBinop.h"
#include "HvControlVar.h"
#include "HvTable.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvControlSlice.h"
#include "HvControlSystem.h"
#include "HvSignalTabwrite.h"
#include "HvSignalVar.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_02ae8cOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QSqQBbjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gOrtEDfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_alCqMelJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YW3sv8xU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1OZR0Au7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0cFtrmMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QdDiDbgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ngAtZV2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7DqZR8OS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i7WrON8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J8qdNQos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OppkBO21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ktg6jKRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nP3vkXky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PHrNEIqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pq6oj3WA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o1S4oaSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ijuINjWt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tGiHHFUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_muZe7YRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LvChgMpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cQxQuFQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TkDYTgEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N6rB5NcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j2gDQcsw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5lUdkyOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zTrM2kxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7zNeb3GL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u8IUuHCH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DNjjAfN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2i7pjPyV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JPUH4q26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fbtLjg9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G2kUbIGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vbutb2A8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JLtlYP44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yIrqdCkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BjOBFNpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gQCAGcJk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wypYrauu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ECZy1n7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kNwgs15T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DvMatgIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NbOIuSGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dc2DEMYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_56b7jUkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iWFr0AMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qFuOJhVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VfjpDDn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FpBp03cP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Pn3J598T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ziVVcW9q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_vQv4V0Uz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_IBHsgGpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g71oq06s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6UbliJR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nXrZae8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fljIoIh9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iuCEhDhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8sMSNMt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OhNLjxbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NZoJPd8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1iv6EMlQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hu8T4P7v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AuGRsDIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DF05SJNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OnBTWho8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U1O3reMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_efUVQll9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pJwxQl5Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AsZPmU4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uIaUkfup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HksZJdYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3egxxNHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RoDD1ngc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jk2UI3ww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Mi2MAgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vDaHcpLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_49FEHVlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LDdXo4aC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RFW6yQjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JD8i1OpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4wgBzYZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fGfoTUjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2wteG8m9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YJH3KjIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hak9tqXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2MbcyUT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H3HK9aKe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AQVuQsuR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A06MA2H9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ejxMvxJU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wWWFXABv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TlqePFM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5jCRiYt5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hrw9q3Ji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z1vCa3fM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WbOXcLgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vS2mbe3S_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Hzh3HMMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2FnwHuqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7oNyD6pD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kePkNDEr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_L71NtAxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rFO31x27_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ihtc3DUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BU3651Pw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dGtKWRsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0DG75C3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w2yxXnpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z5tgD1Rz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2vNNvcBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hmB8e75y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XdhZYnqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KbYPMY5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FsjY8muT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JHJV8YSL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eM6SWNdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ek74Unop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7DcjXngj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YiW7fRav_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JcoskrOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_odq0yqxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qMOIrAnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_4slVukkT;
  SignalPhasor sPhasor_Vu88ZkfU;
  SignalLine sLine_gaLHJMCL;
  SignalRPole sRPole_xhuGSjEj;
  SignalRPole sRPole_dV9dZwqr;
  SignalTabhead sTabhead_QQtJDhte;
  SignalTabread sTabread_PPqE36nr;
  SignalTabread sTabread_w3zHKqNg;
  SignalLine sLine_UaLc54IU;
  SignalTabhead sTabhead_2ZryYObd;
  SignalTabread sTabread_l6tRvSsR;
  SignalTabread sTabread_OYxPP99J;
  SignalLine sLine_0yaDFIlD;
  SignalTabwrite sTabwrite_JL4LqR8I;
  SignalTabwrite sTabwrite_hGGtuxGo;
  ControlVar cVar_02ae8cOW;
  ControlVar cVar_QSqQBbjr;
  ControlVar cVar_gOrtEDfu;
  ControlVar cVar_alCqMelJ;
  ControlBinop cBinop_YW3sv8xU;
  ControlBinop cBinop_1OZR0Au7;
  ControlVar cVar_ngAtZV2e;
  ControlBinop cBinop_i7WrON8z;
  ControlBinop cBinop_OppkBO21;
  SignalVarf sVarf_wX9IlYUH;
  SignalVarf sVarf_rwdndEls;
  SignalVarf sVarf_fgfyiWCp;
  ControlVar cVar_PHrNEIqz;
  ControlBinop cBinop_o1S4oaSZ;
  ControlBinop cBinop_tGiHHFUd;
  SignalVarf sVarf_XgTNQ9XI;
  SignalVarf sVarf_TE54ibm4;
  SignalVarf sVarf_7EkXh9Mb;
  ControlBinop cBinop_muZe7YRv;
  ControlBinop cBinop_LvChgMpn;
  ControlBinop cBinop_N6rB5NcK;
  ControlBinop cBinop_j2gDQcsw;
  ControlBinop cBinop_7zNeb3GL;
  ControlBinop cBinop_DNjjAfN3;
  ControlBinop cBinop_2i7pjPyV;
  ControlBinop cBinop_JPUH4q26;
  ControlBinop cBinop_fbtLjg9c;
  ControlBinop cBinop_G2kUbIGm;
  ControlDelay cDelay_yIrqdCkD;
  ControlDelay cDelay_BjOBFNpm;
  ControlBinop cBinop_wypYrauu;
  HvTable hTable_ECZy1n7p;
  ControlBinop cBinop_DvMatgIY;
  ControlDelay cDelay_FpBp03cP;
  ControlDelay cDelay_Pn3J598T;
  ControlBinop cBinop_vQv4V0Uz;
  HvTable hTable_IBHsgGpT;
  ControlBinop cBinop_6UbliJR1;
  ControlVar cVar_OhNLjxbg;
  ControlBinop cBinop_hu8T4P7v;
  ControlBinop cBinop_AuGRsDIy;
  SignalVarf sVarf_Q3BMEXSE;
  ControlBinop cBinop_OnBTWho8;
  ControlBinop cBinop_U1O3reMP;
  ControlBinop cBinop_efUVQll9;
  SignalVarf sVarf_BJE2HdFp;
  ControlVar cVar_pJwxQl5Z;
  ControlBinop cBinop_HksZJdYz;
  ControlBinop cBinop_3egxxNHn;
  SignalVarf sVarf_DI63XIlr;
  ControlBinop cBinop_jk2UI3ww;
  ControlBinop cBinop_2Mi2MAgW;
  ControlBinop cBinop_vDaHcpLE;
  SignalVarf sVarf_5OYG2F3y;
  ControlBinop cBinop_4wgBzYZA;
  ControlBinop cBinop_fGfoTUjU;
  ControlBinop cBinop_2wteG8m9;
  ControlBinop cBinop_YJH3KjIh;
  ControlBinop cBinop_Hak9tqXN;
  ControlBinop cBinop_H3HK9aKe;
  ControlBinop cBinop_AQVuQsuR;
  ControlSlice cSlice_ejxMvxJU;
  ControlVar cVar_wWWFXABv;
  ControlSlice cSlice_hrw9q3Ji;
  ControlVar cVar_Z1vCa3fM;
  ControlSlice cSlice_Hzh3HMMU;
  ControlVar cVar_2FnwHuqN;
  ControlSlice cSlice_L71NtAxw;
  ControlVar cVar_rFO31x27;
  ControlBinop cBinop_hmB8e75y;
  ControlBinop cBinop_XdhZYnqm;
  ControlBinop cBinop_KbYPMY5J;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
